<template lang="pug">
div
    transition(name="fade" mode="out-in")
        div.modal.fade.show(
            :class="[modalClass, noBorderClass, disableCloseClass]" 
            aria-modal="true" 
            style="display: block" 
            v-if="show" @click.self="hideModal")
          div.modal-dialog.modal-dialog-centered(:class="`modal-${size}`")
            div.modal-content.shadow
              header.modal-header(:class="{'border-bottom-0' : noBorder}" v-if="!hideHeader")
                div.modal-title.w-100(v-if="hasSlotTitle")
                  slot(name="modal-title")
                h5.modal-title.font-weight-600(v-else) {{title}}
                button.close(type="button" aria-label="Close" v-if="!hideClose" @click="hideModal")
                    span.material-icons.icon-lg close
              div.modal-body
                slot
              div.modal-footer(:class="{'border-top-0' :  noBorder}" v-if="!hideFooter || hasSlotFooter")
                slot.w-100(name="modal-footer")
    transition(name="fade")
        div.modal-backdrop(v-if="show")
</template>
<script>
export default {
    name: 'AppModal',
    props: {
        title: {
            type: String,
        },
        size: {
            type: String,
        },
        show: {
            type: Boolean,
            default: false,
        },
        modalClass: {
            type: String,
        },
        hideFooter: {
            type: Boolean,
            default: true,
        },
        hideHeader: {
            type: Boolean,
            default: false,
        },
        hideClose: {
            type: Boolean,
            default: false,
        },
        noBorder: {
            type: Boolean,
            default: false,
        },
        disableClose: {
            type: Boolean,
            default: false,
        },
    },
    watch: {
        show(value) {
            if (value) {
                document.body.classList.add('modal-open')
                this.$root.$el.append(this.$el)
            } else {
                setTimeout(() => {
                    this.$el.parentNode.removeChild(this.$el)
                }, 350)
                document.body.classList.remove('modal-open')
            }
        },
    },
    computed: {
        hasSlotTitle() {
            return !!this.$slots['modal-title']
        },
        hasSlotFooter() {
            return !!this.$slots['modal-footer']
        },
        noBorderClass() {
            return this.noBorder ? 'modal-no-border' : ''
        },
        disableCloseClass() {
            return this.disableClose ? 'modal-disabled' : ''
        },
    },
    methods: {
        hideModal() {
            if (!this.disableClose) this.$emit('hide')
        },
    },
}
</script>

<style lang="scss" scoped src="./index.scss"></style>
